from tortoise import Tortoise, connections
from tortoise.backends.asyncpg import AsyncpgDBClient


async def init_db(conf: dict, create_tables: bool = True) -> AsyncpgDBClient | str:
    await Tortoise.init(conf)
    if create_tables:
        await Tortoise.generate_schemas()
    cn: AsyncpgDBClient = connections.get("default")
    return cn



from pypika_tortoise.terms import AggregateFunction, Field
from tortoise.expressions import Function


class ArrayAgg(AggregateFunction):
    def __init__(self, term, alias=None):
        super(ArrayAgg, self).__init__("array_agg", Field(term), alias=alias)


class Array(Function):
    database_func = ArrayAgg



from asyncio import run
from os import getenv as env
from dotenv import load_dotenv
from tortoise.backends.asyncpg import AsyncpgDBClient

from x_model import init_db, models

load_dotenv()

PG_DSN = f"postgres://{env('POSTGRES_USER')}:{env('POSTGRES_PASSWORD')}@{env('POSTGRES_HOST', 'xyncdbs')}:{env('POSTGRES_PORT', 5432)}/{env('POSTGRES_DB', env('POSTGRES_USER'))}"

TORM = {
    "connections": {"default": PG_DSN},
    "apps": {"models": {"models": [models]}},
    "use_tz": False,
    "timezone": "UTC",
}


def test_init_db():
    assert isinstance(run(init_db(TORM)), AsyncpgDBClient), "DB corrupt"
